@@ -1,4 +1,3 @@
-context("test-layer-spatial-raster.R")
 
 # max test length was exceeded on CRAN, so these tests are skipped
 if (identical(Sys.getenv("NOT_CRAN"), "true")) {
@@ -11,7 +10,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     load_longlake_data(which = c("longlake_osm", "longlake_depthdf", "longlake_depth_raster"), raster_format = "raster")
 
     # should have little grey thing around it
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "layer_spatial.Raster()",
       ggplot() +
         layer_spatial(longlake_osm) +
@@ -19,7 +18,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     )
 
     # should not have little grey thing around it
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "annotation_spatial.Raster()",
       ggplot() +
         annotation_spatial(longlake_osm) +
@@ -27,7 +26,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     )
 
     # grey thing
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "layer_spatial.Raster() project",
       ggplot() +
         layer_spatial(longlake_osm) +
@@ -36,7 +35,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     )
 
     # no grey thing
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "annotation_spatial.Raster() project",
       ggplot() +
         annotation_spatial(longlake_osm) +
@@ -45,7 +44,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     )
 
     # with alpha
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "annotation_spatial.Raster() alpha",
       ggplot() +
         annotation_spatial(longlake_osm, alpha = 0.7) +
@@ -54,19 +53,44 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     )
 
     # with aesthetics
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "layer_spatial.Raster() aes()",
       ggplot() +
         layer_spatial(longlake_osm, aes()) +
         layer_spatial(longlake_depthdf)
     )
 
-    vdiffr::expect_doppelganger(
+    expect_doppelganger_extra(
       "layer_spatial.Raster() aes(band1)",
       ggplot() +
         layer_spatial(longlake_osm, aes(alpha = stat(band1), fill = NULL)) +
         layer_spatial(longlake_depthdf)
     )
+
+    # dpi works
+    vdiffr::expect_doppelganger(
+      "layer_spatial.Raster() dpi",
+      ggplot() +
+        layer_spatial(longlake_osm, lazy = TRUE, dpi = 2)
+    )
+
+    # lazy works
+    vdiffr::expect_doppelganger(
+      "layer_spatial.Raster() lazy",
+      ggplot() +
+        layer_spatial(longlake_osm, lazy = TRUE)
+    )
+
+    # interpolation works
+    vdiffr::expect_doppelganger(
+      "layer_spatial.Raster() no interpolation",
+      ggplot() +
+        layer_spatial(longlake_osm,
+                      lazy = TRUE,
+                      interpolate = FALSE,
+                      dpi = 5
+        )
+    )
   })
 
 }
